CREATE TABLE YAO_PROPERTY (
    NAME VARCHAR(64) PRIMARY KEY,
    VALUE VARCHAR(255),
);
INSERT INTO YAO_PROPERTY VALUES ('schema.version', '4.0.21');
CREATE TABLE YAO_DEFINITIONS (
    ID IDENTITY PRIMARY KEY,
    DEF_ID VARCHAR(64),
    DEF_NAME VARCHAR(255),
    NO_OF_PROCESSES INT,
    DEF_CONTENT BLOB,
    AUTHOR VARCHAR(64),
    COMMENT VARCHAR(500),
    CREATE_TIME TIMESTAMP,
    REVISION INT,
    HEAD SMALLINT
);
CREATE TABLE YAO_DEFINITION (
    ID IDENTITY PRIMARY KEY,
    DEF_ID VARCHAR(64),
    DEF_NAME VARCHAR(255),
    NO_OF_PROCESSES INT,
    DEF_CONTENT BLOB,
    AUTHOR VARCHAR(64),
    COMMENT VARCHAR(500),
    CREATE_TIME TIMESTAMP,
    VERSION INT
);
CREATE TABLE YAO_PROCESS_INSTANCE (
    ID IDENTITY PRIMARY KEY,
    DEF_ID BIGINT,
    DEF_NAME VARCHAR(255),
    VERSION INT,
    PROCESS_GLOBAL_KEY VARCHAR(255),
    PROCESS_ID VARCHAR(64),
    PROCESS_NAME VARCHAR(255),
    OWNER VARCHAR(64),
    STATE VARCHAR(32),
    STATE_TIME TIMESTAMP,
    CREATE_TIME TIMESTAMP,
    FOREIGN KEY(DEF_ID) REFERENCES YAO_DEFINITION(ID)
);
CREATE TABLE YAO_PROCESS_INSTANCE_DATA (
    ID IDENTITY PRIMARY KEY,
    PROCESS_INSTANCE_ID BIGINT,
    SUB_PROCESS_INSTANCE_ID BIGINT,
    LOOP_COUNTER INT,
    DATA_ID VARCHAR(64),
    DATA_NAME VARCHAR(64),
    DATA_TYPE VARCHAR(32),
    DATA_VALUE VARCHAR(255),
    DATA_XML_VALUE BLOB,
    FOREIGN KEY(PROCESS_INSTANCE_ID) REFERENCES YAO_PROCESS_INSTANCE(ID)
);
CREATE TABLE YAO_ACTIVITY_INSTANCE (
    ID IDENTITY PRIMARY KEY,
    PROCESS_INSTANCE_ID BIGINT,
    OUTER_INSTANCE_ID BIGINT,
    ACTIVITY_ID VARCHAR(64),
    ACTIVITY_NAME VARCHAR(64),
    LOOP_COUNTER INT,
    LOOP_CARDINALITY INT,
    STATE VARCHAR(32),
    STATE_TIME TIMESTAMP,
    CREATE_TIME TIMESTAMP,
    FOREIGN KEY(PROCESS_INSTANCE_ID) REFERENCES YAO_PROCESS_INSTANCE(ID)
);
CREATE TABLE YAO_ACTIVITY_INSTANCE_DATA (
    ID IDENTITY PRIMARY KEY,
    PROCESS_INSTANCE_ID BIGINT,
    ACTIVITY_INSTANCE_ID BIGINT,
    LOOP_COUNTER INT,
    DATA_ID VARCHAR(64),
    DATA_NAME VARCHAR(64),
    DATA_TYPE VARCHAR(32),
    DATA_VALUE VARCHAR(255),
    DATA_XML_VALUE BLOB,
    FOREIGN KEY(PROCESS_INSTANCE_ID) REFERENCES YAO_PROCESS_INSTANCE(ID),
    FOREIGN KEY(ACTIVITY_INSTANCE_ID) REFERENCES YAO_ACTIVITY_INSTANCE(ID)
);
CREATE TABLE YAO_WORK_ITEM (
	ID IDENTITY PRIMARY KEY,
    PROCESS_INSTANCE_ID BIGINT,
    OUTER_INSTANCE_ID BIGINT,
	ACTIVITY_INSTANCE_ID BIGINT,
    LOOP_COUNTER INT,
	ACTIVITY_ID VARCHAR(64),
	NAME VARCHAR(64),
	ACTUAL_OWNER VARCHAR(64),
	ACTUAL_OWNER_NAME VARCHAR(64),
	POTENTIAL_OWNER VARCHAR(64),
    STATE VARCHAR(32),
    STATE_TIME TIMESTAMP,
    CREATE_TIME TIMESTAMP,
    FOREIGN KEY(PROCESS_INSTANCE_ID) REFERENCES YAO_PROCESS_INSTANCE(ID),
	FOREIGN KEY(ACTIVITY_INSTANCE_ID) REFERENCES YAO_ACTIVITY_INSTANCE(ID)
);
CREATE TABLE YAO_USER (
    ID IDENTITY PRIMARY KEY,
    USER_CODE VARCHAR(64),
    USER_NAME VARCHAR(64),
    USER_PASSWORD VARCHAR(255)
);
INSERT INTO YAO_USER VALUES (1, 'blenta', 'Blenta', '');
INSERT INTO YAO_USER VALUES (2, 'cher', 'Cher', '');
INSERT INTO YAO_USER VALUES (3, 'admin', 'Admin', '');
CREATE TABLE YAO_GROUP (
    ID IDENTITY PRIMARY KEY,
    GROUP_CODE VARCHAR(64),
    GROUP_NAME VARCHAR(64)
);
INSERT INTO YAO_GROUP VALUES (1, 'accountancy', 'Accountancy');
INSERT INTO YAO_GROUP VALUES (2, 'engineering', 'Engineering');
INSERT INTO YAO_GROUP VALUES (3, 'management', 'Management');
INSERT INTO YAO_GROUP VALUES (4, 'marketing', 'Marketing');
INSERT INTO YAO_GROUP VALUES (5, 'sales', 'Sales');

---------------------------------------------
CREATE TABLE YAO_RESOURCE (
    ID IDENTITY PRIMARY KEY,
    RESOURCE_ID VARCHAR(64),
    RESOURCE_NAME VARCHAR(64)
);
INSERT INTO YAO_RESOURCE VALUES (1, 'simulator', 'Simulator');
CREATE TABLE YAO_PROCESS (
    ID IDENTITY PRIMARY KEY,
    DEF_ID VARCHAR(64),
    DEF_NAME VARCHAR(255),
    PROCESS_ID VARCHAR(64),
    PROCESS_NAME VARCHAR(255),
    PROCESS_TYPE VARCHAR(8),
	IS_EXECUTABLE BOOLEAN,
	IS_CLOSED BOOLEAN,
    STATE TINYINT,
    VERSION INT,
    CREATE_TIME TIMESTAMP
);
CREATE TABLE YAO_FLOW_NODE (
    ID IDENTITY PRIMARY KEY,
    PROCESS_INSTANCE_ID BIGINT,
    FLOW_NODE_ID VARCHAR(64),
    FLOW_NODE_NAME VARCHAR(64),
    STATE VARCHAR(32),
    STATE_TIME TIMESTAMP,
    CREATE_TIME TIMESTAMP,
    FOREIGN KEY(PROCESS_INSTANCE_ID) REFERENCES YAO_PROCESS_INSTANCE(ID)
);
CREATE TABLE YAO_FLOW_NODE_DATA (
    ID IDENTITY PRIMARY KEY,
    PROCESS_INSTANCE_ID BIGINT,
    FLOW_NODE_ID BIGINT,
    DATA_ID VARCHAR(64),
    DATA_NAME VARCHAR(64),
    DATA_TYPE VARCHAR(32),
    DATA_VALUE VARCHAR(255),
    FOREIGN KEY(PROCESS_INSTANCE_ID) REFERENCES YAO_PROCESS_INSTANCE(ID),
    FOREIGN KEY(FLOW_NODE_ID) REFERENCES YAO_FLOW_NODE(ID)
);
CREATE TABLE YAO_ASSIGNMENT (
	ID IDENTITY PRIMARY KEY,
    PROCESS_INSTANCE_ID BIGINT,
	FLOW_NODE_ID BIGINT,
	ASSIGNMENT_ID VARCHAR(64),
	ASSIGNMENT_NAME VARCHAR(64),
	IS_ACCEPTED BOOLEAN,
    FOREIGN KEY(PROCESS_INSTANCE_ID) REFERENCES YAO_PROCESS_INSTANCE(ID),
	FOREIGN KEY(FLOW_NODE_ID) REFERENCES YAO_FLOW_NODE(ID)
);
